@@ -1,14 +1,15 @@
 from Products.Archetypes.public import listTypes
 from Products.Archetypes.Extensions.utils import installTypes, install_subskin
-from Products.ArchAddOn.config import *
+from Products.ArchAddOn.config import PROJECTNAME, GLOBALS
+from Products.ArchAddOn.config import INSTALL_SAMPLE_TYPES
 
 from StringIO import StringIO
 
+
 def install(self):
     out = StringIO()
 
-    # make this true to install sample types
-    if 0:
+    if INSTALL_SAMPLE_TYPES:
         installTypes(self, out,
                      listTypes(PROJECTNAME),
                      PROJECTNAME)
